[![Linux Build
Status](https://travis-ci.org/ioam/parambokeh.svg?branch=master)](https://travis-ci.org/ioam/parambokeh)
[![Windows Build
status](https://ci.appveyor.com/api/projects/status/27h3ybqx51wsasu5/branch/master?svg=true)](https://ci.appveyor.com/project/Ioam/parambokeh/branch/master)

# ParamBokeh

Generate widgets from [Parameterized](https://github.com/ioam/param) objects in Jupyter or in [Bokeh](http://bokeh.pydata.org) Server. See the [documentation](https://ioam.github.io/parambokeh/) for more details.
